{-
   API League

   API League is a Hub for World Class APIs.

   OpenAPI Version: 3.0.0
   API League API version: 1.6.4
   Contact: mail@apileague.com
   Generated by OpenAPI Generator (https://openapi-generator.tech)
-}

{-|
Module : APILeague.API.News
-}

{-# LANGUAGE FlexibleContexts #-}
{-# LANGUAGE FlexibleInstances #-}
{-# LANGUAGE MonoLocalBinds #-}
{-# LANGUAGE MultiParamTypeClasses #-}
{-# LANGUAGE OverloadedStrings #-}
{-# OPTIONS_GHC -fno-warn-name-shadowing -fno-warn-unused-binds -fno-warn-unused-imports #-}

module APILeague.API.News where

import APILeague.Core
import APILeague.MimeTypes
import APILeague.Model as M

import qualified Data.Aeson as A
import qualified Data.ByteString as B
import qualified Data.ByteString.Lazy as BL
import qualified Data.Data as P (Typeable, TypeRep, typeOf, typeRep)
import qualified Data.Foldable as P
import qualified Data.Map as Map
import qualified Data.Maybe as P
import qualified Data.Proxy as P (Proxy(..))
import qualified Data.Set as Set
import qualified Data.String as P
import qualified Data.Text as T
import qualified Data.Text.Encoding as T
import qualified Data.Text.Lazy as TL
import qualified Data.Text.Lazy.Encoding as TL
import qualified Data.Time as TI
import qualified Network.HTTP.Client.MultipartFormData as NH
import qualified Network.HTTP.Media as ME
import qualified Network.HTTP.Types as NH
import qualified Web.FormUrlEncoded as WH
import qualified Web.HttpApiData as WH

import Data.Text (Text)
import GHC.Base ((<|>))

import Prelude ((==),(/=),($), (.),(<$>),(<*>),(>>=),Maybe(..),Bool(..),Char,Double,FilePath,Float,Int,Integer,String,fmap,undefined,mempty,maybe,pure,Monad,Applicative,Functor)
import qualified Prelude as P

-- * Operations


-- ** News

-- *** extractNewsAPI

-- | @GET \/extract-news@
-- 
-- Extract News API
-- 
-- Extract a news article from a website to a well structure JSON object. The API will return the title, text, URL, image, publish date, author, language, source country, and sentiment of the news article.
-- 
-- AuthMethod: 'AuthApiKeyApiKey', 'AuthApiKeyHeaderApiKey'
-- 
extractNewsAPI
  :: Url -- ^ "url" -  The url of the news.
  -> Analyze -- ^ "analyze" -  Whether to analyze the news (extract entities etc.)
  -> APILeagueRequest ExtractNewsAPI MimeNoContent ExtractNewsAPI200Response MimeJSON
extractNewsAPI (Url url) (Analyze analyze) =
  _mkRequest "GET" ["/extract-news"]
    `_hasAuthType` (P.Proxy :: P.Proxy AuthApiKeyApiKey)
    `_hasAuthType` (P.Proxy :: P.Proxy AuthApiKeyHeaderApiKey)
    `addQuery` toQuery ("url", Just url)
    `addQuery` toQuery ("analyze", Just analyze)

data ExtractNewsAPI  
-- | @application/json@
instance Produces ExtractNewsAPI MimeJSON


-- *** searchNewsAPI

-- | @GET \/search-news@
-- 
-- Search News API
-- 
-- Search and filter millions of news from over 200 countries in 90 languages by text, date, location, category, language, and more. The API returns a list of news articles matching the given criteria. You can set as many filtering parameters as you like, but you have to set at least one, e.g. text or language.
-- 
-- AuthMethod: 'AuthApiKeyApiKey', 'AuthApiKeyHeaderApiKey'
-- 
searchNewsAPI
  :: APILeagueRequest SearchNewsAPI MimeNoContent SearchNewsAPI200Response MimeJSON
searchNewsAPI =
  _mkRequest "GET" ["/search-news"]
    `_hasAuthType` (P.Proxy :: P.Proxy AuthApiKeyApiKey)
    `_hasAuthType` (P.Proxy :: P.Proxy AuthApiKeyHeaderApiKey)

data SearchNewsAPI  

-- | /Optional Param/ "text" - The text to match in the news content (at least 3 characters, maximum 100 characters). By default all query terms are expected, you can use an uppercase OR to search for any terms, e.g. tesla OR ford. You can also exclude terms by putting a minus sign (-) in front of the term, e.g. tesla -ford.
instance HasOptionalParam SearchNewsAPI ParamText where
  applyOptionalParam req (ParamText xs) =
    req `addQuery` toQuery ("text", Just xs)

-- | /Optional Param/ "source-countries" - A comma-separated list of ISO 3166 country codes from which the news should originate.
instance HasOptionalParam SearchNewsAPI SourceCountries where
  applyOptionalParam req (SourceCountries xs) =
    req `addQuery` toQuery ("source-countries", Just xs)

-- | /Optional Param/ "language" - The ISO 6391 language code of the news.
instance HasOptionalParam SearchNewsAPI Language where
  applyOptionalParam req (Language xs) =
    req `addQuery` toQuery ("language", Just xs)

-- | /Optional Param/ "min-sentiment" - The minimal sentiment of the news in range [-1,1].
instance HasOptionalParam SearchNewsAPI MinSentiment where
  applyOptionalParam req (MinSentiment xs) =
    req `addQuery` toQuery ("min-sentiment", Just xs)

-- | /Optional Param/ "max-sentiment" - The maximal sentiment of the news in range [-1,1].
instance HasOptionalParam SearchNewsAPI MaxSentiment where
  applyOptionalParam req (MaxSentiment xs) =
    req `addQuery` toQuery ("max-sentiment", Just xs)

-- | /Optional Param/ "earliest-publish-date" - The news must have been published after this date.
instance HasOptionalParam SearchNewsAPI EarliestPublishDate where
  applyOptionalParam req (EarliestPublishDate xs) =
    req `addQuery` toQuery ("earliest-publish-date", Just xs)

-- | /Optional Param/ "latest-publish-date" - The news must have been published before this date.
instance HasOptionalParam SearchNewsAPI LatestPublishDate where
  applyOptionalParam req (LatestPublishDate xs) =
    req `addQuery` toQuery ("latest-publish-date", Just xs)

-- | /Optional Param/ "news-sources" - A comma-separated list of news sources from which the news should originate.
instance HasOptionalParam SearchNewsAPI NewsSources where
  applyOptionalParam req (NewsSources xs) =
    req `addQuery` toQuery ("news-sources", Just xs)

-- | /Optional Param/ "authors" - A comma-separated list of author names. Only news from any of the given authors will be returned.
instance HasOptionalParam SearchNewsAPI Authors where
  applyOptionalParam req (Authors xs) =
    req `addQuery` toQuery ("authors", Just xs)

-- | /Optional Param/ "categories" - A comma-separated list of categories. Only news from any of the given categories will be returned. Possible categories are politics, sports, business, technology, entertainment, health, science, lifestyle, travel, culture, education, environment, other.
instance HasOptionalParam SearchNewsAPI Categories where
  applyOptionalParam req (Categories xs) =
    req `addQuery` toQuery ("categories", Just xs)

-- | /Optional Param/ "entities" - Filter news by entities (ORG, PER, or LOC).
instance HasOptionalParam SearchNewsAPI Entities where
  applyOptionalParam req (Entities xs) =
    req `addQuery` toQuery ("entities", Just xs)

-- | /Optional Param/ "location-filter" - Filter news by radius around a certain location. Format is \"latitude,longitude,radius in kilometers\"
instance HasOptionalParam SearchNewsAPI LocationFilter where
  applyOptionalParam req (LocationFilter xs) =
    req `addQuery` toQuery ("location-filter", Just xs)

-- | /Optional Param/ "sort" - The sorting criteria (publish-time).
instance HasOptionalParam SearchNewsAPI Sort where
  applyOptionalParam req (Sort xs) =
    req `addQuery` toQuery ("sort", Just xs)

-- | /Optional Param/ "sort-direction" - Whether to sort ascending or descending (ASC or DESC).
instance HasOptionalParam SearchNewsAPI SortDirection where
  applyOptionalParam req (SortDirection xs) =
    req `addQuery` toQuery ("sort-direction", Just xs)

-- | /Optional Param/ "offset" - The number of news to skip in range [0,10000]
instance HasOptionalParam SearchNewsAPI Offset where
  applyOptionalParam req (Offset xs) =
    req `addQuery` toQuery ("offset", Just xs)

-- | /Optional Param/ "number" - The number of news to return in range [1,100]
instance HasOptionalParam SearchNewsAPI Number where
  applyOptionalParam req (Number xs) =
    req `addQuery` toQuery ("number", Just xs)
-- | @application/json@
instance Produces SearchNewsAPI MimeJSON


-- *** topNewsAPI

-- | @GET \/retrieve-top-news@
-- 
-- Top News API
-- 
-- Get the top news from a country (over 220 are supported) in a language (over 90 are supported) for a specific date. The top news are clustered from multiple sources in the given country. The more news in a cluster the higher the cluster is ranked.
-- 
-- AuthMethod: 'AuthApiKeyApiKey', 'AuthApiKeyHeaderApiKey'
-- 
topNewsAPI
  :: SourceCountry -- ^ "sourceCountry" -  The ISO 3166 country code of the country for which top news should be retrieved.
  -> Language -- ^ "language" -  The ISO 6391 language code of the top news. The language must be one spoken in the source-country.
  -> APILeagueRequest TopNewsAPI MimeNoContent TopNewsAPI200Response MimeJSON
topNewsAPI (SourceCountry sourceCountry) (Language language) =
  _mkRequest "GET" ["/retrieve-top-news"]
    `_hasAuthType` (P.Proxy :: P.Proxy AuthApiKeyApiKey)
    `_hasAuthType` (P.Proxy :: P.Proxy AuthApiKeyHeaderApiKey)
    `addQuery` toQuery ("source-country", Just sourceCountry)
    `addQuery` toQuery ("language", Just language)

data TopNewsAPI  

-- | /Optional Param/ "date" - The date for which the top news should be retrieved. If no date is given, the current day is assumed.
instance HasOptionalParam TopNewsAPI ParamDate where
  applyOptionalParam req (ParamDate xs) =
    req `addQuery` toQuery ("date", Just xs)

-- | /Optional Param/ "headlines-only" - Whether to only return basic information such as id, title, and url of the news.
instance HasOptionalParam TopNewsAPI HeadlinesOnly where
  applyOptionalParam req (HeadlinesOnly xs) =
    req `addQuery` toQuery ("headlines-only", Just xs)
-- | @application/json@
instance Produces TopNewsAPI MimeJSON

